@@ -1,7 +1,6 @@
 from petsc4py import PETSc
-import unittest
+import unittest, numpy
 from sys import getrefcount
-
 # --------------------------------------------------------------------
 
 class Matrix(object):
@@ -142,6 +141,7 @@ class TestMatrix(unittest.TestCase):
         f = lambda : self.A.diagonalScale(x, y)
         self.assertRaises(Exception, f)
 
+
 class TestIdentity(TestMatrix):
 
     PYCLS = 'Identity'
@@ -178,6 +178,27 @@ class TestIdentity(TestMatrix):
         self.A.getDiagonal(d)
         self.assertTrue(o.equal(d))
 
+    def testH2Opus(self):
+        if not PETSc.Sys.hasExternalPackage("h2opus"):
+            return
+        h = PETSc.Mat()
+
+        # need transpose operation for norm estimation
+        AA = self.A.getPythonContext()
+        AA.multTranspose = AA.mult
+
+        # without coordinates
+        h.createH2OpusFromMat(self.A,leafsize=2)
+        h.assemble()
+        h.destroy()
+
+        # with coordinates
+        coords = numpy.linspace((1,2,3),(10,20,30),self.A.getSize()[0],dtype=PETSc.RealType)
+        h.createH2OpusFromMat(self.A,coords,leafsize=2)
+        h.assemble()
+        h.destroy()
+
+        del AA.multTranspose
 
 class TestDiagonal(TestMatrix):
 
@@ -263,6 +284,7 @@ class TestDiagonal(TestMatrix):
         self.assertTrue(xt.equal(y))
         del A
 
+
 # --------------------------------------------------------------------
 
 if __name__ == '__main__':
